/*
  schip_analog.h - header for interrupt driven analog input
  					with multiple options to be defined

  Copyright (c) 2015 M.Schippling

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General
  Public License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA  02111-1307  USA

  $Id: wiring_analog.h Exp $
*/

#ifndef SCHIP_ANALOG_H
#define SCHIP_ANALOG_H

#include "Arduino.h"

/*** optional operations ***/
#define SCHIPBUFFER	// to include schip's buffering in interrupt
					//  note: not tested combined with SCHIPAVG
#define SBUFSIZE	64	// number of samples to buffer before reporting
// #define SCHIPAVG	// to also do schip's averaging of readings
// #define SCHIPCODE // to include schip's interrupt task scheduler

// note: these are for testing the timing of stuff, not production code
// #define SCHIP_ISRLED	// toggle LED p13 for ADC ISR method length
// #define SCHIP_ADC0PERIOD // toggle LED p13 ADC0 ISR cycle period

// number of ADCs to convert...
//  in order to play nice with I2C on pins shared with ADC4,5
//  this will skip channels 4&5 when SKIPI2C is defined
//  so only 6 conversions are done on each cycle through the set
// can be set to a smaller number as needed...
#define NUM_ADCCHANNEL 4
//#define NUM_ADCCHANNEL 8	// maximum for atmega 328
//#define SCHIPSKIPI2C 		// Skip ADC4,5 for I2C to use instead

// externals for this library
#ifdef __cplusplus
extern "C"{
#endif
extern int analogReadMS( byte pin );	// replaces analogRead()
extern byte analogReadAvgMS( byte pin );	// averaged reading access
extern word *SchipBUF0;	// semaphore from ADC for interrupt buffering
#ifdef __cplusplus
} // extern "C"
#endif

#ifdef SCHIPCODE
#include "schip/scheduler.h"
#endif // SCHIPCODE

#endif // SCHIP_ANALOG_H
